# ListX509CertificateResponse

Response object for X509Certificate list
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**certificates** | [**list[X509Certificate]**](X509Certificate.md) | List of X509Certificate | 
**limit** | **int** | Limit on the number of rows in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


